@@ -38,8 +38,8 @@ from couchdb import json
 from couchdb import util
 
 __all__ = ['HTTPError', 'PreconditionFailed', 'ResourceNotFound',
-           'ResourceConflict', 'ServerError', 'Unauthorized', 'RedirectLimit',
-           'Session', 'Resource']
+           'ResourceConflict', 'ServerError', 'Unauthorized', 'Forbidden',
+           'RedirectLimit', 'Session', 'Resource']
 __docformat__ = 'restructuredtext en'
 
 
@@ -114,6 +114,12 @@ class Unauthorized(HTTPError):
     """
 
 
+class Forbidden(HTTPError):
+    """Exception raised when the request requires an authorisation that the
+    current user does not have.
+    """
+
+
 class RedirectLimit(Exception):
     """Exception raised when a request is redirected more often than allowed
     by the maximum number of redirections.
@@ -362,7 +368,7 @@ class Session(object):
             if num_redirects > self.max_redirects:
                 raise RedirectLimit('Redirection limit exceeded')
             location = resp.getheader('location')
-            
+
             # in case of relative location: add scheme and host to the location
             location_split = util.urlsplit(location)
 
@@ -411,6 +417,8 @@ class Session(object):
                 error = ''
             if status == 401:
                 raise Unauthorized(error)
+            elif status == 403:
+                raise Forbidden(error)
             elif status == 404:
                 raise ResourceNotFound(error)
             elif status == 409:
@@ -573,7 +581,10 @@ class Resource(object):
         all_headers = self.headers.copy()
         all_headers.update(headers or {})
         if path is not None:
-            url = urljoin(self.url, path, **params)
+            if isinstance(path, list):
+                url = urljoin(self.url, *path, **params)
+            else:
+                url = urljoin(self.url, path, **params)
         else:
             url = urljoin(self.url, **params)
         return self.session.request(method, url, body=body,
@@ -592,7 +603,7 @@ class Resource(object):
 def extract_credentials(url):
     """Extract authentication (user name and password) credentials from the
     given URL.
-    
+
     >>> extract_credentials('http://localhost:5984/_config/')
     ('http://localhost:5984/_config/', None)
     >>> extract_credentials('http://joe:secret@localhost:5984/_config/')
@@ -620,8 +631,8 @@ def basic_auth(credentials):
     >>> basic_auth(())
     """
     if credentials:
-        token = b64encode(('%s:%s' % credentials).encode('latin1'))
-        return ('Basic %s' % token.strip().decode('latin1')).encode('ascii')
+        token = b64encode(('%s:%s' % credentials).encode('utf-8'))
+        return ('Basic %s' % token.strip().decode('utf-8')).encode('ascii')
 
 
 def quote(string, safe=''):
